summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrake.ApplicationServices
diff options
context:
space:
mode:
authorScott <[email protected]>2015-10-09 22:37:30 +0100
committerScott <[email protected]>2015-10-09 23:02:34 +0100
commit52206517b2aefe811dae08849442a930d58f43aa (patch)
treea5406e061489f9a185361d8e691a6e3a53eb1e28 /win/CS/HandBrake.ApplicationServices
parentbfa97a7c53e7be2dcc88943b4c3e15eb3ebbf729 (diff)
Updating for the new deinterlace/decomb preset keys.
Diffstat (limited to 'win/CS/HandBrake.ApplicationServices')
-rw-r--r--win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/HBPreset.cs16
1 files changed, 3 insertions, 13 deletions
diff --git a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/HBPreset.cs b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/HBPreset.cs
index 6112a26a3..f84ad3310 100644
--- a/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/HBPreset.cs
+++ b/win/CS/HandBrake.ApplicationServices/Interop/Json/Presets/HBPreset.cs
@@ -122,24 +122,14 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
public int PictureDeblock { get; set; }
/// <summary>
- /// Gets or sets the picture decomb.
- /// </summary>
- public string PictureDecomb { get; set; }
-
- /// <summary>
- /// Gets or sets the picture decomb custom.
- /// </summary>
- public string PictureDecombCustom { get; set; }
-
- /// <summary>
/// Gets or sets a value indicating whether picture decomb deinterlace.
/// </summary>
- public bool PictureDecombDeinterlace { get; set; }
+ public string PictureDeinterlaceFilter { get; set; }
/// <summary>
/// Gets or sets the picture deinterlace.
/// </summary>
- public string PictureDeinterlace { get; set; }
+ public string PictureDeinterlacePreset { get; set; }
/// <summary>
/// Gets or sets the picture deinterlace custom.
@@ -122,24 +122,14 @@ namespace HandBrake.ApplicationServices.Interop.Json.Presets
/// <summary>
- /// Gets or sets the picture deinterlace.
+ /// Gets or sets the picture deinterlace preset.
/// </summary>